@@ -9,6 +9,7 @@ __email__ = "pjmlantunes@gmail.com"
 
 
 from functools import wraps
+
 from flask import render_template, g
 
 
@@ -16,10 +17,7 @@ def validate_args():
     def decorator(f):
         @wraps(f)
         def wrapper(*args, **kwargs):
-            if (
-                "frequency" in kwargs
-                and kwargs["frequency"] not in g.HISTORY_FREQUENCY
-            ):
+            if "frequency" in kwargs and kwargs["frequency"] not in g.HISTORY_FREQUENCY:
                 return (
                     render_template(
                         template_name_or_list="error.html",
