@@ -9,15 +9,16 @@ __email__ = "pjmlantunes@gmail.com"
 
 
 from datetime import datetime
+
 from mongoengine import Q
 from mongoengine.errors import DoesNotExist, ValidationError
-from xtcryptosignals.tasks.models.history import History
-from xtcryptosignals.tasks.models.cfgi import CFGI
-from xtcryptosignals.tasks.models.tether import Tether
-from xtcryptosignals.tasks.models.project_twitter import ProjectTwitter
+
 from xtcryptosignals.server.api.projects.models import Project
 from xtcryptosignals.tasks import settings as s
-
+from xtcryptosignals.tasks.models.cfgi import CFGI
+from xtcryptosignals.tasks.models.history import History
+from xtcryptosignals.tasks.models.project_twitter import ProjectTwitter
+from xtcryptosignals.tasks.models.tether import Tether
 
 NUM_OCCURRENCES = 30  # CFGI_MIN=1d in client
 
@@ -41,15 +42,11 @@ def get_chart_fear_and_greed_index(frequency, coin_or_token):
         source=ref["name"],
     )[:NUM_OCCURRENCES]
 
-    btc_prices = {
-        x.created_on.strftime("%Y-%m-%d"): int(x.price_usdt) for x in rows
-    }
+    btc_prices = {x.created_on.strftime("%Y-%m-%d"): int(x.price_usdt) for x in rows}
 
     cfgi_values = {
         x.added_on.strftime("%Y-%m-%d"): x.index
-        for x in CFGI.objects[
-            : (NUM_OCCURRENCES * 12)
-        ]  # CFGI_MAX=12w in client
+        for x in CFGI.objects[: (NUM_OCCURRENCES * 12)]  # CFGI_MAX=12w in client
     }
 
     days = list(btc_prices.keys())
@@ -95,9 +92,7 @@ def get_chart_coin_or_token_frequency(coin_or_token, frequency):
     volumes.reverse()
     num_trades.reverse()
 
-    return dict(
-        prices=prices, volumes=volumes, num_trades=num_trades, quote="USDT"
-    )
+    return dict(prices=prices, volumes=volumes, num_trades=num_trades, quote="USDT")
 
 
 def _normalize_ts(ts, frequency):
@@ -106,8 +101,7 @@ def _normalize_ts(ts, frequency):
     else:
         kwargs = dict(hour=0, minute=0, second=0, microsecond=0)
     return (
-        datetime.timestamp(datetime.fromtimestamp(ts / 1000).replace(**kwargs))
-        * 1000
+        datetime.timestamp(datetime.fromtimestamp(ts / 1000).replace(**kwargs)) * 1000
     )
 
 
@@ -126,9 +120,7 @@ def get_chart_tether_btc(coin_or_token, frequency):
     btc_prices = {}
     for row in rows:
         obj = row.to_dict(frequency=frequency)
-        btc_prices[_normalize_ts(obj["created_on_ts"], frequency)] = obj[
-            "price_usdt"
-        ]
+        btc_prices[_normalize_ts(obj["created_on_ts"], frequency)] = obj["price_usdt"]
 
     tether = {}
     for row in Tether.objects[: (NUM_OCCURRENCES * 8 * 12)]:
