@@ -12,6 +12,7 @@ from marshmallow import (
     Schema,
     fields,
 )
+
 from xtcryptosignals.server.api.common.schemas import OutputSchema
 
 
@@ -29,9 +30,7 @@ class NotificationsOutputSchema(OutputSchema):
 
 
 class NotificationOutputSchema(Schema):
-    notifications = fields.Nested(
-        NotificationsOutputSchema, many=True, required=True
-    )
+    notifications = fields.Nested(NotificationsOutputSchema, many=True, required=True)
     coin_tokens = fields.Raw(many=True, required=True)
 
 
