@@ -10,10 +10,10 @@ __email__ = "pjmlantunes@gmail.com"
 
 import eventlet
 from flask_socketio import Namespace
-from xtcryptosignals.server import socketio
-from xtcryptosignals.tasks.models.history import History
-from xtcryptosignals.tasks import settings as s
 
+from xtcryptosignals.server import socketio
+from xtcryptosignals.tasks import settings as s
+from xtcryptosignals.tasks.models.history import History
 
 eventlet.monkey_patch()
 
@@ -58,7 +58,5 @@ class TickerSocketIONamespace(Namespace):
 
 
 for x in s.HISTORY_FREQUENCY:
-    socketio_model = type(
-        f"SocketIONamespace{x}", (TickerSocketIONamespace,), {}
-    )
+    socketio_model = type(f"SocketIONamespace{x}", (TickerSocketIONamespace,), {})
     socketio.on_namespace(socketio_model(f"/{x}"))
