@@ -26,9 +26,7 @@ class CoinbasePro:
 
             request = requests.get(url)
             if request.status_code != 200:
-                raise ValueError(
-                    "Error connecting CoinbasePro on URL: {}".format(url)
-                )
+                raise ValueError(f"Error connecting CoinbasePro on URL: {url}")
             item.update(request.json())
 
         item.update(symbol="".join(symbol), ticker=symbol[0])
